<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="utf-8">
    <meta name="description"
        content="SEKOLAH TINGGI ILMU TARBIYAH INSIDA adalah pilihan terbaik untuk kuliah vokasi di Balikpapan. Menyediakan program D3 Bahasa Inggris, D4 Manajemen Pemasaran Internasional, dan D4 Kesehatan dan Keselamatan Kerja dengan biaya terjangkau dan fasilitas lengkap untuk mendukung pendidikan berkualitas." />
    <meta name="keywords"
        content="SEKOLAH TINGGI ILMU TARBIYAH INSIDA, kuliah vokasi Balikpapan, D3 Bahasa Inggris, D4 Manajemen Pemasaran Internasional, D4 Kesehatan dan Keselamatan Kerja,
        kuliah murah Balikpapan, kuliah karyawan, kuliah jarak jauh, biaya kuliah STIE GANESHA, kampus Balikpapan, pendidikan vokasi Kalimantan,
        politeknik terbaik Kalimantan Timur, pendaftaran STIE GANESHA, kampus kompetitif STIE GANESHA, edunitas, kuliah berkualitas Kalimantan,
        politeknik unggulan Balikpapan" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

    <title>404 Not Found &mdash; SEKOLAH TINGGI ILMU TARBIYAH INSIDA(Kelas Karyawan)</title>
    <meta property="og:title" content="SEKOLAH TINGGI ILMU TARBIYAH INSIDA">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://stit-insida.info/">
    <meta property="og:image" content="https://stit-insida.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200">
    <meta property="og:image:height" content="630">
    <meta property="og:description"
        content="SEKOLAH TINGGI ILMU TARBIYAH INSIDA menyediakan pendidikan vokasi unggul dengan program D3 dan D4. Biaya terjangkau, lokasi strategis di Balikpapan, dan dosen profesional menjadikan kampus ini pilihan ideal untuk masa depan gemilang." />
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@stit-insida">
    <meta name="twitter:site" content="@stit-insida">
    <meta name="twitter:title" content="SEKOLAH TINGGI ILMU TARBIYAH INSIDA">
    <meta name="twitter:description"
        content="Kuliah di SEKOLAH TINGGI ILMU TARBIYAH INSIDA: Program D3 dan D4 dengan biaya terjangkau dan fasilitas modern. Cocok untuk mahasiswa yang ingin pendidikan vokasi berkualitas di Balikpapan." />
    <meta name="twitter:domain" content="https://stit-insida.info/">
    <meta name="twitter:image:src" content="https://stit-insida.info/images/background/hero1.png">
    <meta name="author" content="Tim IT STIE GANESHA">
    <meta http-equiv="cache-control" content="public">
    <meta name="application-name" content="SEKOLAH TINGGI ILMU TARBIYAH INSIDA">
    <meta name="msapplication-TileColor" content="#2A9D8F">
    <meta name="theme-color" content="#2A9D8F">

    <!-- Alamat Kampus -->
    <meta name="geo.placename"
        content="Jl. Indrakila, Gn. Samarinda, Kec. Balikpapan Utara, Kota Balikpapan, Kalimantan Timur 76124">

    <!-- Struktur Data untuk SEO Lokal -->
    <script type="application/ld+json">
    {
    "@context": "https://schema.org",
    "@type": "EducationalOrganization",
    "name": "SEKOLAH TINGGI ILMU TARBIYAH INSIDA",
    "url": "https://stit-insida.info/",
    "address": {
        "@type": "PostalAddress",
        "streetAddress": "Jl. Indrakila, Gn. Samarinda, Kec. Balikpapan Utara",
        "addressLocality": "Balikpapan",
        "addressRegion": "Kalimantan Timur",
        "postalCode": "76124",
        "addressCountry": "ID"
    },
    "contactPoint": {
        "@type": "ContactPoint",
        "telephone": "+62 812-3456-7890",
        "contactType": "customer service"
    }
    }
    </script>


    <link rel="apple-touch-icon" sizes="57x57" href="<?php echo e(asset('images/favicons/apple-icon-57x57.png')); ?>">
    <link rel="apple-touch-icon" sizes="60x60" href="<?php echo e(asset('images/favicons/apple-icon-60x60.png')); ?>">
    <link rel="apple-touch-icon" sizes="72x72" href="<?php echo e(asset('images/favicons/apple-icon-72x72.png')); ?>">
    <link rel="apple-touch-icon" sizes="76x76" href="<?php echo e(asset('images/favicons/apple-icon-76x76.png')); ?>">
    <link rel="apple-touch-icon" sizes="114x114" href="<?php echo e(asset('images/favicons/apple-icon-114x114.png')); ?>">
    <link rel="apple-touch-icon" sizes="120x120" href="<?php echo e(asset('images/favicons/apple-icon-120x120.png')); ?>">
    <link rel="apple-touch-icon" sizes="144x144" href="<?php echo e(asset('images/favicons/apple-icon-144x144.png')); ?>">
    <link rel="apple-touch-icon" sizes="152x152" href="<?php echo e(asset('images/favicons/apple-icon-152x152.png')); ?>">
    <link rel="apple-touch-icon" sizes="180x180" href="<?php echo e(asset('images/favicons/apple-icon-180x180.png')); ?>">
    <link rel="icon" type="image/png" sizes="192x192"
        href="<?php echo e(asset('images/favicons/android-icon-192x192.png')); ?>">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php echo e(asset('images/favicons/favicons-32x32.png')); ?>">
    <link rel="icon" type="image/png" sizes="96x96" href="<?php echo e(asset('images/favicons/favicons-96x96.png')); ?>">
    <link rel="icon" type="image/png" sizes="16x16" href="<?php echo e(asset('images/favicons/favicons-16x16.png')); ?>">
    <link rel="manifest" href="images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">


    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap"
        rel="stylesheet">
    <link href="./css/app.css" rel="stylesheet">
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">
    
    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>

</head>

<body>

    
    <div class="h-auto flex flex-col items-center justify-center md:gap-x-[100px] py-[100px] pt-[150px] px-4 md:px-0 bg-cover bg-no-repeat bg-left md:bg-center-top h-screen"
        style="background-image: url('<?php echo e(asset('./images/404/404bg.png')); ?>');">
        <div class="flex flex-col md:flex-row justify-center items-center gap-6 md:gap-10 px-4 md:px-0">
            <img src="<?php echo e(asset('images/404/404teksweb.png')); ?>" class="w-full max-w-[400px] h-auto"
                alt="404 Not Found">
            <!-- Teks -->
            <div class="text-center md:text-left font-poppins text-[#353C4F]">
                <h1 class="text-xl md:text-2xl lg:text-3xl font-extrabold">Oppss..., Halaman Tidak Ditemukan</h1>
                <h2 class="text-sm md:text-base lg:text-lg font-normal">
                    Mohon maaf, halaman yang Anda cari tidak ada.
                </h2>
                <a href="/kontak-form"
                    class="inline-flex items-center justify-center bg-gradient-to-r from-[#353C4F] to-[#4161B7] hover:bg-gradient-to-br text-white font-bold py-2 px-6 rounded-full text-sm md:text-base lg:text-lg mt-4">
                    <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24"
                        class=" inline-block mr-2">
                        <path fill="currentColor" d="M10 19l-7-7 7-7v4h8v6h-8v4z" />
                    </svg>
                    Kembali Ke Home
                </a>
            </div>
        </div>
    </div>
    
    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>



    
    <script src="https://www.google.com/recaptcha/api.js" async defer></script>
    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="./js/app.js"></script>
    <script src="./js/daftaronline.js"></script>
    <script src="<?php echo e(asset('./js/app.js')); ?>"></script>
    <script>
        document.addEventListener('contextmenu', function(event) {
            event.preventDefault();
            alert('Right Click Disabled.');
        });
    </script>
</body>

</html>
<?php /**PATH /home/u768956174/domains/stit-insida.info/stit-insida/resources/views/errors/404.blade.php ENDPATH**/ ?>