@section('title', 'Visi Misi')
@extends('Frontend.Layouts.app2')
@section('content')
    <x-header-section-page title="Visi Misi STIT SEKOLAH TINGGI ILMU TARBIYAH INSIDA " breadcrumb-home="Home" breadcrumb-current="Visi Misi" />

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    Sekolah Tinggi Ilmu Tarbiyah INSIDA Jakarta pada tahun 2028 sebagai lembaga pendidikan tinggi terkemuka
                    dalam mengintegrasikan aspek ke-ilmuan, ke-Islaman, dan ke-Indonesiaan.
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                    <li>
                        Menyelenggarakan Pendidikan dan Pembelajaran yang berkualitas.
                    </li>
                    <li>
                        Menyelenggarakan Penelitian yang inovatif untuk menghasilkan temuan baru dan bermanfaat bagi
                        masyarakat.
                    </li>
                    <li>
                        Menyelenggarakan pengabdian kepada masyarakat yang solutif untuk pemberdayaan masyarakat.
                    </li>
                </ul>
            </div>
            <!-- Tujuan -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Tujuan</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                    <li>Menghasilkan sarjana yang memahami dasar-dasar ilmu pendidikan ke islaman secara profesional.
                    </li>
                    <li>
                        Menghasilkan karya ilmiah yang mampu memberikan kontribusi sebesar-besarnya untuk kepentingan
                        masyarakat.
                    </li>
                    <li>
                        Menghasilkan sarjana yang berfikir kritis, mandiri, terbuka, inovatif dan kreatif dan bermanfaat
                        bagi masyarakat.
                    </li>
                </ul>
            </div>

            <!-- Tujuan -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Sasaran dan Strategi
                    Pencapaiannya</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    Dari rumusan visi dan misi di atas, memiliki sasaran dan strategi pencapaian sebagai berikut:
                </p>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                    <li>Menyelenggarakan pendidikan dan pengajaran di bidang Ilmu Pendidikan Islam
                    </li>
                    <li>
                        Menyusun kurikulum berbasis kompetensi yang dapat menghasilkan output yang memiliki landasan
                        keilmuan yang kuat dan integritas moral.
                    </li>
                    <li>
                        Menyelenggarakan program-program bersama lembaga/instansi Pemerintah dan swasta yang terkait dengan
                        pendidikan ke islamanan.
                    </li>
                    <li>
                        Menyediakan tenaga dosen dan karyawan yang profesional dan berdedikasi tinggi.
                    </li>
                    <li>
                        Menyediakan literatur yang mendukung peningkatan kualitas akademik dan wawasan keilmuan.
                    </li>
                    <li>
                        Meningkatkan kualitas dan kuantitas penelitian dosen dan mahasiswa ditingkat institusi, lokal, dan
                        nasional.
                    </li>
                    <li>
                        Meningkatkan pengabdian terhadap masyarakat oleh dosen dan mahasiswa.
                    </li>
                    <li>
                        Menatalaksanakan manajemen dalam rangka pelayanan yang prima terhadap civitas akademik
                        dan masyarakat secara luas.
                    </li>
                </ul>
            </div>

            <!-- Call to Action -->
            <x-join-us-section title="Bergabunglah Bersama SEKOLAH TINGGI ILMU TARBIYAH INSIDA"
                description="Bersama Sekolah Tinggi Ilmu Tarbiyah, wujudkan impian Anda, raih ilmu yang bermanfaat dengan bimbingan para ahli. Jadilah generasi yang cerdas, berakhlak, dan berdaya saing tinggi."
                buttonText="Daftar Sekarang" />
        </div>
    </div>
@endsection
