<div class="my-3">
    <a href="<?php echo e($url); ?>"
        class="text-white w-[180px] duration-200 md:w-[240px] hover:rounded-full font-Anek bg-gradient-to-r from-[#020183] to-[#FFEF03] font-poppins hover:bg-gradient-to-br font-normal rounded-full text-[14px] px-4 md:px-5 py-2.5 text-center me-2 mb-4 md:mb-2">
        <?php echo e($slot); ?>

    </a>
</div>
<?php /**PATH /home/u768956174/domains/stit-insida.info/stit-insida/resources/views/components/button.blade.php ENDPATH**/ ?>