#navbar {
    width: 100%;
    position: fixed;
    top: 0;
    left: 0;
    z-index: 1000;
    transition: background 0.5s ease-in-out;
}

/* Navbar transparan hanya di halaman "/" sebelum scroll */
#navbar.transparent {
    background: transparent;
}

/* Navbar berubah saat di-scroll atau di halaman lain */
#navbar.scrolled {
    background: linear-gradient(rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0.5)),
        url("/images/background/footer1.png");
    background-size: cover;
    background-position: center;
}
