<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="utf-8">
    <meta name="description"
        content="SEKOLAH TINGGI ILMU TARBIYAH INSIDA (STIT INSIDA) adalah salah satu Perguruan Tinggi Swasta terbaik di Jakarta Timur. Menyediakan program S1 Pendidikan Agama Islam, S1 Pendidikan Islam Anak Usia Dini, dan S1 Pendidikan Guru Madrasah Ibtidaiyah dengan biaya terjangkau mulai dari Rp 390.000/bulan. Cocok bagi mahasiswa yang ingin kuliah dengan sistem fleksibel serta didukung fasilitas modern dan dosen berpengalaman." />
    <meta name="keywords"
        content="Kelas karyawan, Kuliah karyawan, SEKOLAH TINGGI ILMU TARBIYAH INSIDA, STIT INSIDA, biaya kuliah STIT INSIDA, kampus murah Jakarta Timur, S1 Pendidikan Agama Islam,
         S1 Pendidikan Islam Anak Usia Dini, S1 Pendidikan Guru Madrasah Ibtidaiyah, kuliah online, kuliah fleksibel, kampus akreditasi baik, Edunitas, kampus berkualitas,
          pendidikan vokasi Jakarta Timur, edunitas" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

    <title>Cetak &mdash; SEKOLAH TINGGI ILMU TARBIYAH INSIDA (STIT INSIDA)</title>
    <meta property="og:title" content="SEKOLAH TINGGI ILMU TARBIYAH INSIDA">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://stit-insida.info">
    <meta property="og:image" content="https://stit-insida.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200">
    <meta property="og:image:height" content="630">
    <meta property="og:description"
        content="STIT INSIDA menyediakan pendidikan berkualitas dengan biaya terjangkau. Program S1 dengan fasilitas modern dan dosen berpengalaman, ideal bagi mahasiswa yang ingin meningkatkan keahlian di bidang pendidikan Islam." />
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@stitinsida">
    <meta name="twitter:site" content="@stitinsida">
    <meta name="twitter:title" content="SEKOLAH TINGGI ILMU TARBIYAH INSIDA">
    <meta name="twitter:description"
        content="Kuliah di STIT INSIDA: Sistem pembelajaran fleksibel yang memungkinkan mahasiswa untuk kuliah sambil bekerja dengan biaya terjangkau dan fasilitas lengkap." />
    <meta name="twitter:domain" content="https://stit-insida.info">
    <meta name="twitter:image:src" content="https://stit-insida.info/images/background/hero1.png">
    <meta name="author" content="Tim IT STIT INSIDA">
    <meta http-equiv="cache-control" content="public">
    <meta name="application-name" content="SEKOLAH TINGGI ILMU TARBIYAH INSIDA">
    <meta name="msapplication-TileColor" content="#2A9D8F">
    <meta name="theme-color" content="#2A9D8F">

    <!-- Alamat Kampus -->
    <meta name="geo.placename" content="Jl. Malaka Hijau Raya No. 45, Pondok Kopi - Jakarta Timur 13460">

    <!-- Struktur Data untuk SEO Lokal -->
    <script type="application/ld+json">
{
  "@context": "https://schema.org",
  "@type": "EducationalOrganization",
  "name": "SEKOLAH TINGGI ILMU TARBIYAH INSIDA",
  "url": "https://stit-insida.info",
  "address": {
    "@type": "PostalAddress",
    "streetAddress": "Jl. Malaka Hijau Raya No. 45, Pondok Kopi - Jakarta Timur 13460",
    "addressLocality": "Jakarta Timur",
    "addressRegion": "DKI Jakarta",
    "postalCode": "13460",
    "addressCountry": "ID"
  },
  "contactPoint": {
    "@type": "ContactPoint",
    "telephone": "+62 812-3456-7890",
    "contactType": "customer service"
  },
  "offers": {
    "@type": "EducationalOccupationalProgram",
    "name": "Program Sarjana S1",
    "provider": {
      "@type": "EducationalOrganization",
      "name": "SEKOLAH TINGGI ILMU TARBIYAH INSIDA"
    },
    "hasCourse": [
      {
        "@type": "Course",
        "name": "S1 Pendidikan Agama Islam",
        "educationalProgramMode": "full-time",
        "offers": {
          "@type": "Offer",
          "price": "390000",
          "priceCurrency": "IDR"
        }
      },
      {
        "@type": "Course",
        "name": "S1 Pendidikan Islam Anak Usia Dini",
        "educationalProgramMode": "full-time",
        "offers": {
          "@type": "Offer",
          "price": "390000",
          "priceCurrency": "IDR"
        }
      },
      {
        "@type": "Course",
        "name": "S1 Pendidikan Guru Madrasah Ibtidaiyah",
        "educationalProgramMode": "full-time",
        "offers": {
          "@type": "Offer",
          "price": "390000",
          "priceCurrency": "IDR"
        }
      }
    ]
  }
}
</script>

    <link rel="apple-touch-icon" sizes="57x57" href="<?php echo e(asset('images/favicons/apple-icon-57x57.png')); ?>">
    <link rel="apple-touch-icon" sizes="60x60" href="<?php echo e(asset('images/favicons/apple-icon-60x60.png')); ?>">
    <link rel="apple-touch-icon" sizes="72x72" href="<?php echo e(asset('images/favicons/apple-icon-72x72.png')); ?>">
    <link rel="apple-touch-icon" sizes="76x76" href="<?php echo e(asset('images/favicons/apple-icon-76x76.png')); ?>">
    <link rel="apple-touch-icon" sizes="114x114" href="<?php echo e(asset('images/favicons/apple-icon-114x114.png')); ?>">
    <link rel="apple-touch-icon" sizes="120x120" href="<?php echo e(asset('images/favicons/apple-icon-120x120.png')); ?>">
    <link rel="apple-touch-icon" sizes="144x144" href="<?php echo e(asset('images/favicons/apple-icon-144x144.png')); ?>">
    <link rel="apple-touch-icon" sizes="152x152" href="<?php echo e(asset('images/favicons/apple-icon-152x152.png')); ?>">
    <link rel="apple-touch-icon" sizes="180x180" href="<?php echo e(asset('images/favicons/apple-icon-180x180.png')); ?>">
    <link rel="icon" type="image/png" sizes="192x192"
        href="<?php echo e(asset('images/favicons/android-icon-192x192.png')); ?>">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php echo e(asset('images/favicons/favicons-32x32.png')); ?>">
    <link rel="icon" type="image/png" sizes="96x96" href="<?php echo e(asset('images/favicons/favicons-96x96.png')); ?>">
    <link rel="icon" type="image/png" sizes="16x16" href="<?php echo e(asset('images/favicons/favicons-16x16.png')); ?>">
    <link rel="manifest" href="images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">


    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap"
        rel="stylesheet">
    <link href="./css/app.css" rel="stylesheet">
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />

    
    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>

</head>

<body>

    <div class="bg-gray-50 py-10">
        <div class="container mx-auto max-w-screen-lg bg-white shadow-lg rounded-lg p-8">
            <div class="text-center border-b-4 border-primary pb-4">
                <img class="w-32 mx-auto mb-4" src="<?php echo e(asset('./images/logo/logo1.png')); ?>"
                    alt="SEKOLAH TINGGI ILMU TARBIYAH INSIDA Logo">
                <h2 class="text-2xl font-poppins font-bold text-primary uppercase">
                    FORMULIR PENDAFTARAN
                    <br>CALON MAHASISWA BARU SEKOLAH TINGGI ILMU TARBIYAH INSIDA
                </h2>
            </div>

            <div class="mt-6">
                <table class="w-full text-sm font-dmsans text-primary">
                    <!-- Nomor Pendaftaran -->
                    <tr>
                        <td class="py-2 font-medium">Nomor Pendaftaran</td>
                        <td>:</td>
                        <td class="text-accent font-semibold">PO_<?php echo e($data->daftar_id); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Perguruan Tinggi</td>
                        <td>:</td>
                        <td>SEKOLAH TINGGI ILMU TARBIYAH INSIDA</td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Jurusan</td>
                        <td>:</td>
                        <td><?php echo e($data->jurusan); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Wawancara Via</td>
                        <td>:</td>
                        <td><?php echo e($data->no_hp); ?></td>
                    </tr>
                </table>
            </div>

            <div class="mt-8">
                <h3 class="text-lg font-semibold text-primary border-b pb-2">DATA PRIBADI</h3>
                <table class="w-full mt-4 text-sm font-dmsans text-primary">
                    <tr>
                        <td class="py-2 font-medium">Nama</td>
                        <td>:</td>
                        <td class="text-accent font-semibold"><?php echo e($data->nama_leng); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Jenis Kelamin</td>
                        <td>:</td>
                        <td><?php echo e($data->j_kel == 'L' ? 'Laki-laki' : 'Perempuan'); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Tempat Lahir</td>
                        <td>:</td>
                        <td><?php echo e($data->tmpt_lahir); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Tanggal Lahir</td>
                        <td>:</td>
                        <td><?php echo e($data->tgl_lahir); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Nama Ibu Kandung</td>
                        <td>:</td>
                        <td><?php echo e($data->ibu); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Alamat Surat/Rumah</td>
                        <td>:</td>
                        <td><?php echo e($data->al_dom); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Nomor Telepon</td>
                        <td>:</td>
                        <td><?php echo e($data->no_hp); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Nomor WhatsApp</td>
                        <td>:</td>
                        <td><?php echo e($data->no_wa); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Email</td>
                        <td>:</td>
                        <td><?php echo e($data->email); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Ukuran Alamamater</td>
                        <td>:</td>
                        <td><?php echo e($data->jaket); ?></td>
                    </tr>
                </table>
            </div>

            <div class="mt-8">
                <h3 class="text-lg font-semibold text-primary border-b pb-2">DATA PENDIDIKAN</h3>
                <table class="w-full mt-4 text-sm font-dmsans text-primary">
                    <tr>
                        <td class="py-2 font-medium">Asal Lulusan</td>
                        <td>:</td>
                        <td><?php echo e($data->lulusan); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Nama Sekolah</td>
                        <td>:</td>
                        <td><?php echo e($data->sekolah); ?></td>
                    </tr>
                </table>
            </div>

            <div class="mt-8">
                <h3 class="text-lg font-semibold text-primary border-b pb-2">DATA PEKERJAAN</h3>
                <table class="w-full mt-4 text-sm font-dmsans text-primary">
                    <tr>
                        <td class="py-2 font-medium">Nama Pekerjaan</td>
                        <td>:</td>
                        <td><?php echo e($data->kerja); ?></td>
                    </tr>
                    <tr>
                        <td class="py-2 font-medium">Alamat Pekerjaan</td>
                        <td>:</td>
                        <td><?php echo e($data->al_kerja); ?></td>
                    </tr>
                </table>
            </div>

            <div class="flex justify-between items-center mt-12">
                <div>
                    <p class="font-medium">SEKOLAH TINGGI ILMU TARBIYAH INSIDA</p>
                    <img class="w-24 mt-2" src="<?php echo e(asset('images/ttd_cap_fix.png')); ?>" alt="TTD Cap">
                    <p class="mt-2 font-medium">STAFF PMB</p>
                </div>
                <div>
                    <p><?php echo e(date('d-m-Y')); ?></p>
                    <p>Calon Mahasiswa,</p>
                    <br><br><br>
                    <p class="font-semibold text-accent"><?php echo e(strtoupper($data->nama_leng)); ?></p>
                </div>
            </div>

            <div class="text-center mt-8">
                <button id="printpagebutton" onclick="printpage()"
                    class="px-4 py-2 bg-primary text-white rounded-md hover:bg-accent">
                    Cetak
                </button>
            </div>
        </div>
    </div>

    <script>
        function printpage() {
            const printButton = document.getElementById("printpagebutton");
            printButton.style.visibility = 'hidden';
            window.print();
            printButton.style.visibility = 'visible';
        }
    </script>

    
    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>

    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="./js/app.js"></script>
    <script src="<?php echo e(asset('./js/app.js')); ?>"></script>
</body>

</html>
<?php /**PATH /home/u768956174/domains/stit-insida.info/stit-insida/resources/views/Frontend/cetak.blade.php ENDPATH**/ ?>