<div class="w-auto pb-6 py-4 border-b border-gray-300 mb-6">
    <div class="flex items-center gap-x-3">
        <div class="w-2 h-6 md:h-8 bg-gradient-to-b from-[#020183] to-[#FFEF03] rounded-full"></div>
        <h2 class="text-[16px] md:text-[18px] uppercase font-medium text-gray-700 tracking-wide w-[400px]"
            style="color: <?php echo e($subtextColor); ?>;">
            <?php echo e($subtext); ?>

        </h2>
    </div>
</div>
<?php /**PATH /home/u768956174/domains/stit-insida.info/stit-insida/resources/views/components/header-section.blade.php ENDPATH**/ ?>