<?php $__env->startSection('title', 'Detail-Berita'); ?>
<?php $__env->startSection('content'); ?>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => ''.e($berita->judul).'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'berita']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>
    <div class="bg-gray-50 rounded-lg p-6 shadow-md mt-8 md:mx-[50px] " data-aos="fade-up">
        <img src="<?php echo e(asset('./storage/berita/' . $berita->file_foto)); ?>"
            class="rounded-lg w-full h-auto object-cover object-center" alt="">
        <p class="mt-8 font-dmsans text-[14px] md:text-[16px] lg:text-[18px] " style="text-indent: 30px;" data-aos="fade-up">
            <?php echo e(strip_tags($berita->content)); ?>

        </p>
        <?php if (isset($component)) { $__componentOriginalb00b7f394457213486d153818d225395159e3717 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\JoinUsSection::class, ['title' => 'Bergabunglah Bersama SEKOLAH TINGGI ILMU TARBIYAH INSIDA','description' => 'Pilih STIT sebagai jalan menuju masa depan cerah, tempat Anda tumbuh dengan ilmu dan karakter mulia. Bersama kami, ciptakan perubahan positif bagi umat dan bangsa.','buttonText' => 'Daftar Sekarang']); ?>
<?php $component->withName('join-us-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginalb00b7f394457213486d153818d225395159e3717)): ?>
<?php $component = $__componentOriginalb00b7f394457213486d153818d225395159e3717; ?>
<?php unset($__componentOriginalb00b7f394457213486d153818d225395159e3717); ?>
<?php endif; ?>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/u768956174/domains/stit-insida.info/stit-insida/resources/views/Frontend/detail-berita.blade.php ENDPATH**/ ?>