<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('{{ asset('./images/background/footer1.png') }}');">
    <div class="flex justify-center md:justify-start w-full md:w-auto">
        <img src="{{ asset('./images/sambutan/rektor.png') }}" data-aos="fade-up"
            class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" alt="">
    </div>
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">
        <x-header-section subtext="Direktur SEKOLAH TINGGI ILMU TARBIYAH INSIDA" subtext-color="#FFFFFF" title=""
            title-color="#F9F51A" />
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base text-white normal-case w-[80%]">
            Sekolah Tinggi Ilmu Tarbiyah (STIT) INSIDA adalah sebuah Lembaga Penyelenggaraan Pendidikan Tinggi yang
            mengkaji dan dan mengembangkan ilmu agama islam, khususnya ilmu ketarbiyahan dibawah naungan Yayasan
            Pendidikan Nasional Latansa yang dirintis sejak 2002, yang telah terakreditasi BAN-PT dengan hasil “Baik"
        </p>

        <x-button url="/sejarah-singkat">BACA SELENGKAPNYA</x-button>
    </div>
</div>
