<?php $__env->startSection('title', 'Struktur Organisasi'); ?>

<?php $__env->startSection('content'); ?>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Struktur Organisasi STIT INSIDA','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Struktur Organisasi']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class="py-16 mt-4">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-20">

            

            <!-- Organizational Structure Section -->
            <div class="bg-white shadow-xl shadow rounded-lg p-6 grid grid-cols-1 md:grid-cols-2 gap-6">
                <!-- Struktur Periode 2023 – 2026 -->
                <div>
                    <h3 class="text-primary text-xl font-semibold mb-4 font-poppins">Periode 2023 – 2026</h3>
                    <ul class="list-disc font-dmsans list-inside">
                        <li>Ketua: Dr. Hasnida, M. Pd.</li>
                        <li>Puket I Akademik & Perencanaan: Dr. M. Misbah, M.Pd.I</li>
                        <li>Puket II Administrasi dan Keuangan: Farida, M. Pd</li>
                        <li>Puket III Kemahasiswaan & Alumni: Asep Kusnadi, M. Pd.</li>
                        <li>Puket IV Kerjasama: Dr. Husni Alhan, MA.</li>
                        <li>Ka. Prodi PAI: Dr. M. Misbah, M.Pd.I</li>
                        <li>Ka. Prodi PIAUD: Farida, M. Pd</li>
                        <li>Ka. Prodi PGMI: Kosim, M. Pd.I</li>
                    </ul>
                </div>

                <!-- Struktur Periode 2017 – 2022 -->
                <div class="mt-8">
                    <h3 class="text-primary text-xl font-semibold mb-4 font-poppins">Periode 2017 – 2022</h3>
                    <ul class="list-disc font-dmsans list-inside">
                        <li>Ketua: Dr. Rafiqurrahman, MA</li>
                        <li>Puket I Akademik: Drs. M. Fakhuruddin, M.Si</li>
                        <li>Puket II Administrasi dan Keuangan: Farida, M.Pd</li>
                        <li>Puket III Kemahasiswaan: Muh. Misbah, M.Pd.I</li>
                        <li>KA. Prodi PAI dan PGMI: Miftachul Huda, M.Pd.I</li>
                        <li>KA. Prodi PIAUD: Hasnida, M. Pd.</li>
                    </ul>
                </div>

                <!-- Struktur Periode 2013 – 2017 -->
                <div class="mt-8">
                    <h3 class="text-primary text-xl font-semibold mb-4 font-poppins">Periode 2013 – 2017</h3>
                    <ul class="list-disc font-dmsans list-inside">
                        <li>Ketua: Prof. Dr. H. Ridlo Masduki</li>
                        <li>Puket I Akademik: Dr. Rafiqurrahman, MA</li>
                        <li>Puket II Administrasi dan Keuangan: Farida, M.Pd</li>
                        <li>Puket III Kemahasiswaan: Miftachul Huda, M.Pd.I</li>
                        <li>KA. Prodi: M. Misbah, M.Pd.I</li>
                        <li>Sek. Prodi: Hasnida, M. Pd.</li>
                    </ul>
                </div>

                <!-- Struktur Periode 2009 – 2013 -->
                <div class="mt-8">
                    <h3 class="text-primary text-xl font-semibold mb-4 font-poppins">Periode 2009 – 2013</h3>
                    <ul class="list-disc font-dmsans list-inside">
                        <li>Ketua: Prof. Dr. H. Ridlo Masduki</li>
                        <li>Puket I Akademik: Dr. Rafiqurrahman, MA</li>
                        <li>Puket II Administrasi dan Keuangan: Farida, M.Pd</li>
                        <li>Puket III Kemahasiswaan: Miftachul Huda, M.Pd.I</li>
                        <li>KA. Prodi: M. Misbah, M.Pd.I</li>
                        <li>Sek. Prodi: Hasnida, M. Pd.</li>
                    </ul>
                </div>
            </div>

            <!-- Join Us Section -->
            <?php if (isset($component)) { $__componentOriginalb00b7f394457213486d153818d225395159e3717 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\JoinUsSection::class, ['title' => 'Bergabunglah Bersama SEKOLAH TINGGI ILMU TARBIYAH INSIDA','description' => 'Jadilah bagian dari keluarga besar STIT INSIDA,
kampus yang mengutamakan kualitas dan karakter.
Temukan inspirasi, asah kreativitas, dan terus melangkah,
menuju karier yang gemilang dan bermakna.','buttonText' => 'Daftar Sekarang']); ?>
<?php $component->withName('join-us-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginalb00b7f394457213486d153818d225395159e3717)): ?>
<?php $component = $__componentOriginalb00b7f394457213486d153818d225395159e3717; ?>
<?php unset($__componentOriginalb00b7f394457213486d153818d225395159e3717); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/u768956174/domains/stit-insida.info/stit-insida/resources/views/Frontend/struktur.blade.php ENDPATH**/ ?>