<div data-aos="fade-up" class="text-center shadow-xl mt-5">
    <div data-aos="fade-up" class="bg-gradient-to-r from-[#020183] to-[#FFEF03] py-8 rounded-lg">
        <h2 data-aos="fade-up" class="text-xl font-poppins font-bold text-white mb-3 uppercase">
            <?php echo e($title); ?>

        </h2>
        <p data-aos="fade-up" class="text-white font-dmsans mb-5 mx-6">
            "<?php echo e($description); ?>"
        </p>
        <a href="/pendaftaran" data-aos="fade-up"
            class="bg-gradient-to-r from-[#020183] to-[#FFEF03] hover:bg-gradient-to-br text-white font-poppins font-medium py-2 px-6 rounded-full shadow-md transition">
            <?php echo e($buttonText); ?>

        </a>
    </div>
</div>
<?php /**PATH /home/u768956174/domains/stit-insida.info/stit-insida/resources/views/components/join-us-section.blade.php ENDPATH**/ ?>