 <p class="text-white text-xs md:text-sm lg:text-base text-center hidden">Copyright © 2024 - @milhammubarrok.gmail.com
 </p>
<?php /**PATH /home/u768956174/domains/stit-insida.info/stit-insida/resources/views/components/footer.blade.php ENDPATH**/ ?>