<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('<?php echo e(asset('./images/background/footer1.png')); ?>');">
    <div class="flex justify-center md:justify-start w-full md:w-auto">
        <img src="<?php echo e(asset('./images/sambutan/rektor.png')); ?>" data-aos="fade-up"
            class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" alt="">
    </div>
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">
        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => 'Direktur SEKOLAH TINGGI ILMU TARBIYAH INSIDA','subtextColor' => '#FFFFFF','title' => '','titleColor' => '#F9F51A']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base text-white normal-case w-[80%]">
            Sekolah Tinggi Ilmu Tarbiyah (STIT) INSIDA adalah sebuah Lembaga Penyelenggaraan Pendidikan Tinggi yang
            mengkaji dan dan mengembangkan ilmu agama islam, khususnya ilmu ketarbiyahan dibawah naungan Yayasan
            Pendidikan Nasional Latansa yang dirintis sejak 2002, yang telah terakreditasi BAN-PT dengan hasil “Baik"
        </p>

        <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/sejarah-singkat']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>BACA SELENGKAPNYA <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
    </div>
</div>
<?php /**PATH /home/u768956174/domains/stit-insida.info/stit-insida/resources/views/Frontend/landingpage/sambutan-section.blade.php ENDPATH**/ ?>