@section('title', 'Sejarah')
@extends('Frontend.Layouts.app2')
@section('content')
    <x-header-section-page title="Tentang STIT INSIDA" breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class="flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <div data-aos="fade-up"
            class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px] bg-white shadow-xl rounded-lg p-6">
            <p class="first-line:pl-5">
                Sekolah Tinggi Ilmu Tarbiyah (STIT) INSIDA adalah sebuah Lembaga Penyelenggaraan Pendidikan Tinggi yang
                mengkaji dan mengembangkan ilmu agama Islam, khususnya ilmu ketarbiyahan di bawah naungan Yayasan
                Pendidikan Nasional Latansa yang dirintis sejak 2002, dan telah terakreditasi BAN-PT dengan hasil “Baik”.
            </p>
            <img src="https://www.stit-insida.ac.id/wp-content/uploads/2023/05/sapto-aipt-akreditasi-institusi-stit-insida.png"
                alt="">
            <p>
                Dalam perkembangannya, STIT INSIDA memiliki 3 Program Studi, yaitu:
            </p>
            <ul class="list-disc list-inside">
                <li>Pendidikan Agama Islam (PAI), Terakreditasi B –> <a class="text-blue-500"
                        href="https://sapto.banpt.or.id/c/213469/6504">Lihat Akreditasi</a></li>
                <li>Pendidikan Islam Anak Usia Dini (PIAUD), Terakreditasi Baik –> <a class="text-blue-500"
                        href="https://akreditasi.lamdik.or.id/pub/ak/e02d324ea1e04ce4ac0c452ee53798ef">Lihat Akreditasi</a>
                </li>
                <li>Pendidikan Guru Madrasah Ibtidaiyah (PGMI), Terakreditasi Baik –> <a class="text-blue-500"
                        href="https://sapto.banpt.or.id/c/213469/34881">Lihat Akreditasi</a></li>
            </ul>

            <h2 class="text-lg font-semibold mt-4">Informasi Institusi</h2>
            <p><strong>Nomor SK Pendirian PS:</strong> Dj.II/27/2005 (22 Maret 2005)</p>
            <p><strong>Nomor SK Ijin Operasional:</strong> 009 Tahun 2003 (22 Juni 2003)</p>
            <p><strong>Nomor SK BAN-PT Institusi:</strong> 2678/SK/BAN-PT/Akred/PT/VIII/2017</p>
            <p><strong>Nomor SK BAN-PT Prodi PAI Terakhir:</strong> 192/SK/BAN-PT/Ak-XVI/S/IX/2013 (Peringkat “B” Nilai :
                340)</p>
            <p><strong>Nomor SK Dirjen Prodi PIAUD:</strong> Nomor 2013 Tahun 2016</p>
            <p><strong>Nomor SK Dirjen Prodi PGMI:</strong> Nomor 3453 Tahun 2017</p>
        </div>

        <x-join-us-section title="Bergabunglah Bersama SEKOLAH TINGGI ILMU TARBIYAH INSIDA"
            description="STIT hadir untuk membentuk insan berilmu dan berakhlak, membangun pemimpin berwawasan luas dengan semangat keislaman. Jadilah bagian dari perubahan dengan pendidikan terbaik."
            buttonText="Daftar Sekarang" buttonLink="/pendaftaran" />
    </div>
@endsection
