<?php $__env->startSection('title', 'Kontak'); ?>


<?php $__env->startSection('content'); ?>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Contact SEKOLAH TINGGI ILMU TARBIYAH INSIDA','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Contact Us']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class="py-10 bg-gray-50 shadow-xl mt-10">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16">
            <div data-aos="fade-up" class="grid grid-cols-1 lg:grid-cols-2 gap-8">
                <!-- Informasi Kontak -->
                <div data-aos="fade-up" class="bg-white shadow-md rounded-lg p-6">
                    <h3 data-aos="fade-up"
                        class="text-xl font-semibold text-transparent bg-gradient-to-r from-[#020183] to-[#FFEF03] bg-clip-text mb-4 font-poppins">
                        Alamat Kampus &
                        Sekretariat</h3>
                    <p data-aos="fade-up" class="text-gray-600 mb-6 font-dmsans">Jl. Malaka Hijau Raya No. 45, Pondok Kopi -
                        Jakarta Timur 13460
                    </p>
                    <h3 data-aos="fade-up"
                        class="text-xl font-semibold text-transparent bg-gradient-to-r from-[#020183] to-[#FFEF03] bg-clip-text mb-4 font-poppins">
                        Call & SMS Center
                    </h3>
                    <p data-aos="fade-up" class="text-gray-600 font-dmsans">
                        <span data-aos="fade-up" class="font-semibold font-dmsans">Telepon :</span> 0878-9019-8284<br>
                        <span data-aos="fade-up" class="font-semibold font-dmsans">Whatsapp :</span> 087818000395
                    </p>
                </div>

                <!-- Gambar Representatif -->
                <div data-aos="fade-up" class="flex justify-center">
                    <img src="http://piaud.stit-insida.ac.id/wp-content/uploads/2023/01/Gedung-STIT-INSIDA-Web.jpg"
                        alt="Gedung Kampus" class="rounded-lg shadow-lg w-full md:w-3/4 lg:w-2/3">
                </div>
            </div>

            <!-- Google Maps -->
            <div data-aos="fade-up" class="mt-10">
                <iframe
                    src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d376.4243333893003!2d106.93977641060286!3d-6.224697159289652!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x2e698cecdd568f9f%3A0x256e8cd1b9cbb292!2sSEKOLAH%20TINGGI%20ILMU%20TARBIYAH%20INSIDA!5e0!3m2!1sen!2sid!4v1742353362265!5m2!1sen!2sid"
                    width="100%" height="400" style="border:0;" allowfullscreen="" loading="lazy"
                    referrerpolicy="no-referrer-when-downgrade" data-aos="fade-up" class="rounded-lg shadow-md"></iframe>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/u768956174/domains/stit-insida.info/stit-insida/resources/views/Frontend/kontak.blade.php ENDPATH**/ ?>